from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fdb:
	"""Fdb commands group definition. 15 total commands, 10 Sub-groups, 0 group commands
	Repeated Capability: FdbTransmitter, default value after init: FdbTransmitter.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fdb", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_fdbTransmitter_get', 'repcap_fdbTransmitter_set', repcap.FdbTransmitter.Nr1)

	def repcap_fdbTransmitter_set(self, enum_value: repcap.FdbTransmitter) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FdbTransmitter.Default
		Default value after init: FdbTransmitter.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_fdbTransmitter_get(self) -> repcap.FdbTransmitter:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def aid(self):
		"""aid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aid'):
			from .Aid import Aid
			self._aid = Aid(self._core, self._base)
		return self._aid

	@property
	def atcHeight(self):
		"""atcHeight commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atcHeight'):
			from .AtcHeight import AtcHeight
			self._atcHeight = AtcHeight(self._core, self._base)
		return self._atcHeight

	@property
	def ddlocation(self):
		"""ddlocation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ddlocation'):
			from .Ddlocation import Ddlocation
			self._ddlocation = Ddlocation(self._core, self._base)
		return self._ddlocation

	@property
	def dpLocation(self):
		"""dpLocation commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dpLocation'):
			from .DpLocation import DpLocation
			self._dpLocation = DpLocation(self._core, self._base)
		return self._dpLocation

	@property
	def gpAngle(self):
		"""gpAngle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gpAngle'):
			from .GpAngle import GpAngle
			self._gpAngle = GpAngle(self._core, self._base)
		return self._gpAngle

	@property
	def rletter(self):
		"""rletter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rletter'):
			from .Rletter import Rletter
			self._rletter = Rletter(self._core, self._base)
		return self._rletter

	@property
	def rnumber(self):
		"""rnumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rnumber'):
			from .Rnumber import Rnumber
			self._rnumber = Rnumber(self._core, self._base)
		return self._rnumber

	@property
	def rpdf(self):
		"""rpdf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpdf'):
			from .Rpdf import Rpdf
			self._rpdf = Rpdf(self._core, self._base)
		return self._rpdf

	@property
	def rpif(self):
		"""rpif commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpif'):
			from .Rpif import Rpif
			self._rpif = Rpif(self._core, self._base)
		return self._rpif

	@property
	def ruIndicator(self):
		"""ruIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ruIndicator'):
			from .RuIndicator import RuIndicator
			self._ruIndicator = RuIndicator(self._core, self._base)
		return self._ruIndicator

	def clone(self) -> 'Fdb':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fdb(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ploss:
	"""Ploss commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ploss", core, parent)

	def set(self, path_loss_state: bool, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:POWer:PLOSs \n
		Snippet: driver.source.bb.gnss.svid.glonass.power.ploss.set(path_loss_state = False, satelliteSvid = repcap.SatelliteSvid.Default) \n
		If enabled, the power of the SV ID signals is reduced to account for the free space attenuation. \n
			:param path_loss_state: 0| 1| OFF| ON
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.bool_to_str(path_loss_state)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:POWer:PLOSs {param}')

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:POWer:PLOSs \n
		Snippet: value: bool = driver.source.bb.gnss.svid.glonass.power.ploss.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		If enabled, the power of the SV ID signals is reduced to account for the free space attenuation. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: path_loss_state: 0| 1| OFF| ON"""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:POWer:PLOSs?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Unit:
	"""Unit commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("unit", core, parent)

	# noinspection PyTypeChecker
	def get_angle(self) -> enums.UnitAngle:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:ANGLe \n
		Snippet: value: enums.UnitAngle = driver.source.regenerator.unit.get_angle() \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the angle via remote control, the angle units must be specified. \n
			:return: unit: DEGree| DEGRee| RADian
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:UNIT:ANGLe?')
		return Conversions.str_to_scalar_enum(response, enums.UnitAngle)

	def set_angle(self, unit: enums.UnitAngle) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:ANGLe \n
		Snippet: driver.source.regenerator.unit.set_angle(unit = enums.UnitAngle.DEGree) \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the angle via remote control, the angle units must be specified. \n
			:param unit: DEGree| DEGRee| RADian
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.UnitAngle)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:UNIT:ANGLe {param}')

	# noinspection PyTypeChecker
	def get_length(self) -> enums.UnitLengthReg:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:LENGth \n
		Snippet: value: enums.UnitLengthReg = driver.source.regenerator.unit.get_length() \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the range or the distance via remote control, the units must be
		specified. \n
			:return: unit: MI| NM| KM| M
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:UNIT:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.UnitLengthReg)

	def set_length(self, unit: enums.UnitLengthReg) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:LENGth \n
		Snippet: driver.source.regenerator.unit.set_length(unit = enums.UnitLengthReg.KM) \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the range or the distance via remote control, the units must be
		specified. \n
			:param unit: MI| NM| KM| M
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.UnitLengthReg)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:UNIT:LENGth {param}')

	# noinspection PyTypeChecker
	def get_velocity(self) -> enums.UnitSpeed:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:VELocity \n
		Snippet: value: enums.UnitSpeed = driver.source.regenerator.unit.get_velocity() \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the velocity via remote control, the velocity units must be specified. \n
			:return: unit: MPS| KMH| MPH| NMPH
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:UNIT:VELocity?')
		return Conversions.str_to_scalar_enum(response, enums.UnitSpeed)

	def set_velocity(self, unit: enums.UnitSpeed) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:UNIT:VELocity \n
		Snippet: driver.source.regenerator.unit.set_velocity(unit = enums.UnitSpeed.KMH) \n
		Sets the default unit for the parameter as displayed in the dialog. Note: This command changes only the units displayed
		in the graphical user interface. While configuring the velocity via remote control, the velocity units must be specified. \n
			:param unit: MPS| KMH| MPH| NMPH
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.UnitSpeed)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:UNIT:VELocity {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ccoding:
	"""Ccoding commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ccoding", core, parent)

	@property
	def isf(self):
		"""isf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_isf'):
			from .Isf import Isf
			self._isf = Isf(self._core, self._base)
		return self._isf

	@property
	def nsf(self):
		"""nsf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsf'):
			from .Nsf import Nsf
			self._nsf = Nsf(self._core, self._base)
		return self._nsf

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def tbsi(self):
		"""tbsi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbsi'):
			from .Tbsi import Tbsi
			self._tbsi = Tbsi(self._core, self._base)
		return self._tbsi

	@property
	def tbSize(self):
		"""tbSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbSize'):
			from .TbSize import TbSize
			self._tbSize = TbSize(self._core, self._base)
		return self._tbSize

	def clone(self) -> 'Ccoding':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ccoding(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Use:
	"""Use commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("use", core, parent)

	def set(self, use: bool, userIx=repcap.UserIx.Default, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:SCRambling:CELL<ST>:DMRS:USE \n
		Snippet: driver.source.bb.eutra.downlink.user.scrambling.cell.dmrs.use.set(use = False, userIx = repcap.UserIx.Default, cell = repcap.Cell.Default) \n
		Defines how the DMRS scrambling sequence is initialized. \n
			:param use: 0| 1| OFF| ON OFF DRMS sequence is generated with the variable nID = NIDcell. ON Used are two variable nID = nIDDMRS,i set with the commands [:SOURcehw]:BB:EUTRa:DL:USERch:SCRambling:CELLst:DMRS:ID1|ID2
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.bool_to_str(use)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:SCRambling:CELL{cell_cmd_val}:DMRS:USE {param}')

	def get(self, userIx=repcap.UserIx.Default, cell=repcap.Cell.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:SCRambling:CELL<ST>:DMRS:USE \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.user.scrambling.cell.dmrs.use.get(userIx = repcap.UserIx.Default, cell = repcap.Cell.Default) \n
		Defines how the DMRS scrambling sequence is initialized. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: use: 0| 1| OFF| ON OFF DRMS sequence is generated with the variable nID = NIDcell. ON Used are two variable nID = nIDDMRS,i set with the commands [:SOURcehw]:BB:EUTRa:DL:USERch:SCRambling:CELLst:DMRS:ID1|ID2"""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:SCRambling:CELL{cell_cmd_val}:DMRS:USE?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Powc:
	"""Powc commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("powc", core, parent)

	# noinspection PyTypeChecker
	def get_lev_reference(self) -> enums.PowcLevRef:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:LEVReference \n
		Snippet: value: enums.PowcLevRef = driver.source.bb.v5G.powc.get_lev_reference() \n
		No command help available \n
			:return: level_reference: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:POWC:LEVReference?')
		return Conversions.str_to_scalar_enum(response, enums.PowcLevRef)

	def set_lev_reference(self, level_reference: enums.PowcLevRef) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:LEVReference \n
		Snippet: driver.source.bb.v5G.powc.set_lev_reference(level_reference = enums.PowcLevRef.DRMS) \n
		No command help available \n
			:param level_reference: No help available
		"""
		param = Conversions.enum_scalar_to_str(level_reference, enums.PowcLevRef)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:POWC:LEVReference {param}')

	# noinspection PyTypeChecker
	def get_ref_channel(self) -> enums.PowcRefChan:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:REFChannel \n
		Snippet: value: enums.PowcRefChan = driver.source.bb.v5G.powc.get_ref_channel() \n
		No command help available \n
			:return: ref_channel: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:POWC:REFChannel?')
		return Conversions.str_to_scalar_enum(response, enums.PowcRefChan)

	def set_ref_channel(self, ref_channel: enums.PowcRefChan) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:REFChannel \n
		Snippet: driver.source.bb.v5G.powc.set_ref_channel(ref_channel = enums.PowcRefChan.NF) \n
		No command help available \n
			:param ref_channel: No help available
		"""
		param = Conversions.enum_scalar_to_str(ref_channel, enums.PowcRefChan)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:POWC:REFChannel {param}')

	def get_ref_subframe(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:REFSubframe \n
		Snippet: value: int = driver.source.bb.v5G.powc.get_ref_subframe() \n
		No command help available \n
			:return: ref_subframe: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:POWC:REFSubframe?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_rue(self) -> enums.MobStatType:
		"""SCPI: [SOURce<HW>]:BB:V5G:POWC:RUE \n
		Snippet: value: enums.MobStatType = driver.source.bb.v5G.powc.get_rue() \n
		No command help available \n
			:return: reference_ue: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:POWC:RUE?')
		return Conversions.str_to_scalar_enum(response, enums.MobStatType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fdoppler:
	"""Fdoppler commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fdoppler", core, parent)

	@property
	def actual(self):
		"""actual commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_actual'):
			from .Actual import Actual
			self._actual = Actual(self._core, self._base)
		return self._actual

	def get(self, path=repcap.Path.Default) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:BIRThdeath:PATH<CH>:FDOPpler \n
		Snippet: value: float = driver.source.fsimulator.birthDeath.path.fdoppler.get(path = repcap.Path.Default) \n
		Queries the resulting Doppler frequency with birth death propagation. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')
			:return: fdoppler: float Range: 0 to 1000"""
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:BIRThdeath:PATH{path_cmd_val}:FDOPpler?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Fdoppler':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fdoppler(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BpFrame:
	"""BpFrame commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bpFrame", core, parent)

	def get(self, cell=repcap.Cell.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:CELL<ST>:ENH:DCH:BPFRame \n
		Snippet: value: str = driver.source.bb.tdscdma.down.cell.enh.dch.bpFrame.get(cell = repcap.Cell.Default) \n
		Queries the data bits in the DPDCH component of the DPCH frame at physical level. The value depends on the slot format. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: bp_frame: string"""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:CELL{cell_cmd_val}:ENH:DCH:BPFRame?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoEntries:
	"""NoEntries commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("noEntries", core, parent)

	def set(self, no_entries: int, groupNull=repcap.GroupNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:GRPS:GT<ST0>:AFON:NOENtries \n
		Snippet: driver.source.bb.stereo.grps.gt.afon.noEntries.set(no_entries = 1, groupNull = repcap.GroupNull.Default) \n
		No command help available \n
			:param no_entries: No help available
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Gt')"""
		param = Conversions.decimal_value_to_str(no_entries)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:GRPS:GT{groupNull_cmd_val}:AFON:NOENtries {param}')

	def get(self, groupNull=repcap.GroupNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:STEReo:GRPS:GT<ST0>:AFON:NOENtries \n
		Snippet: value: int = driver.source.bb.stereo.grps.gt.afon.noEntries.get(groupNull = repcap.GroupNull.Default) \n
		No command help available \n
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Gt')
			:return: no_entries: No help available"""
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:STEReo:GRPS:GT{groupNull_cmd_val}:AFON:NOENtries?')
		return Conversions.str_to_int(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TtInterval:
	"""TtInterval commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ttInterval", core, parent)

	def set(self, tt_interval: enums.TchTranTimInt, channelNull=repcap.ChannelNull.Default, transportChannelNull=repcap.TransportChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:TCHannel<DI0>:TTINterval \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.tchannel.ttInterval.set(tt_interval = enums.TchTranTimInt._10MS, channelNull = repcap.ChannelNull.Default, transportChannelNull = repcap.TransportChannelNull.Default) \n
		Sets the number of frames into which a TCH is divided. This setting also defines the interleaver depth. \n
			:param tt_interval: 10MS| 20MS| 40MS
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param transportChannelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tchannel')"""
		param = Conversions.enum_scalar_to_str(tt_interval, enums.TchTranTimInt)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		transportChannelNull_cmd_val = self._base.get_repcap_cmd_value(transportChannelNull, repcap.TransportChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:TCHannel{transportChannelNull_cmd_val}:TTINterval {param}')

	# noinspection PyTypeChecker
	def get(self, channelNull=repcap.ChannelNull.Default, transportChannelNull=repcap.TransportChannelNull.Default) -> enums.TchTranTimInt:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:TCHannel<DI0>:TTINterval \n
		Snippet: value: enums.TchTranTimInt = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.tchannel.ttInterval.get(channelNull = repcap.ChannelNull.Default, transportChannelNull = repcap.TransportChannelNull.Default) \n
		Sets the number of frames into which a TCH is divided. This setting also defines the interleaver depth. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:param transportChannelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tchannel')
			:return: tt_interval: 10MS| 20MS| 40MS"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		transportChannelNull_cmd_val = self._base.get_repcap_cmd_value(transportChannelNull, repcap.TransportChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:TCHannel{transportChannelNull_cmd_val}:TTINterval?')
		return Conversions.str_to_scalar_enum(response, enums.TchTranTimInt)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mcode:
	"""Mcode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mcode", core, parent)

	def set(self, mcode: bool, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:DPCCh:MCODe \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.dpcch.mcode.set(mcode = False, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command activates multicode transmission for the selected channel (ON) or deactivates it (OFF) . The multicode
		channels are destined for the same receiver, that is to say, are part of a radio link. The first channel of this group is
		used as the master channel. The common components (Pilot, TPC and TCFI) for all the channels are then spread using the
		spreading code of the master channel. \n
			:param mcode: 0| 1| OFF| ON
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.bool_to_str(mcode)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:DPCCh:MCODe {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:DPCCh:MCODe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.channel.dpcch.mcode.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command activates multicode transmission for the selected channel (ON) or deactivates it (OFF) . The multicode
		channels are destined for the same receiver, that is to say, are part of a radio link. The first channel of this group is
		used as the master channel. The common components (Pilot, TPC and TCFI) for all the channels are then spread using the
		spreading code of the master channel. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: mcode: 0| 1| OFF| ON"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:DPCCh:MCODe?')
		return Conversions.str_to_bool(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DciConf:
	"""DciConf commands group definition. 31 total commands, 31 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dciConf", core, parent)

	@property
	def apnLayer(self):
		"""apnLayer commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apnLayer'):
			from .ApnLayer import ApnLayer
			self._apnLayer = ApnLayer(self._core, self._base)
		return self._apnLayer

	@property
	def bitData(self):
		"""bitData commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bitData'):
			from .BitData import BitData
			self._bitData = BitData(self._core, self._base)
		return self._bitData

	@property
	def bmi(self):
		"""bmi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmi'):
			from .Bmi import Bmi
			self._bmi = Bmi(self._core, self._base)
		return self._bmi

	@property
	def bsi(self):
		"""bsi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bsi'):
			from .Bsi import Bsi
			self._bsi = Bsi(self._core, self._base)
		return self._bsi

	@property
	def cbbRequest(self):
		"""cbbRequest commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbbRequest'):
			from .CbbRequest import CbbRequest
			self._cbbRequest = CbbRequest(self._core, self._base)
		return self._cbbRequest

	@property
	def cbProcess(self):
		"""cbProcess commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbProcess'):
			from .CbProcess import CbProcess
			self._cbProcess = CbProcess(self._core, self._base)
		return self._cbProcess

	@property
	def cbSymbol(self):
		"""cbSymbol commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbSymbol'):
			from .CbSymbol import CbSymbol
			self._cbSymbol = CbSymbol(self._core, self._base)
		return self._cbSymbol

	@property
	def ctrTiming(self):
		"""ctrTiming commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctrTiming'):
			from .CtrTiming import CtrTiming
			self._ctrTiming = CtrTiming(self._core, self._base)
		return self._ctrTiming

	@property
	def cycShift(self):
		"""cycShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cycShift'):
			from .CycShift import CycShift
			self._cycShift = CycShift(self._core, self._base)
		return self._cycShift

	@property
	def dlPcrs(self):
		"""dlPcrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlPcrs'):
			from .DlPcrs import DlPcrs
			self._dlPcrs = DlPcrs(self._core, self._base)
		return self._dlPcrs

	@property
	def fbi(self):
		"""fbi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fbi'):
			from .Fbi import Fbi
			self._fbi = Fbi(self._core, self._base)
		return self._fbi

	@property
	def hpn(self):
		"""hpn commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hpn'):
			from .Hpn import Hpn
			self._hpn = Hpn(self._core, self._base)
		return self._hpn

	@property
	def mcsr(self):
		"""mcsr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsr'):
			from .Mcsr import Mcsr
			self._mcsr = Mcsr(self._core, self._base)
		return self._mcsr

	@property
	def ndi(self):
		"""ndi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndi'):
			from .Ndi import Ndi
			self._ndi = Ndi(self._core, self._base)
		return self._ndi

	@property
	def nscid(self):
		"""nscid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nscid'):
			from .Nscid import Nscid
			self._nscid = Nscid(self._core, self._base)
		return self._nscid

	@property
	def occIndicator(self):
		"""occIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_occIndicator'):
			from .OccIndicator import OccIndicator
			self._occIndicator = OccIndicator(self._core, self._base)
		return self._occIndicator

	@property
	def pmi(self):
		"""pmi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmi'):
			from .Pmi import Pmi
			self._pmi = Pmi(self._core, self._base)
		return self._pmi

	@property
	def rba(self):
		"""rba commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rba'):
			from .Rba import Rba
			self._rba = Rba(self._core, self._base)
		return self._rba

	@property
	def remap(self):
		"""remap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remap'):
			from .Remap import Remap
			self._remap = Remap(self._core, self._base)
		return self._remap

	@property
	def rv(self):
		"""rv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rv'):
			from .Rv import Rv
			self._rv = Rv(self._core, self._base)
		return self._rv

	@property
	def srsRequest(self):
		"""srsRequest commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srsRequest'):
			from .SrsRequest import SrsRequest
			self._srsRequest = SrsRequest(self._core, self._base)
		return self._srsRequest

	@property
	def srsSymbol(self):
		"""srsSymbol commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srsSymbol'):
			from .SrsSymbol import SrsSymbol
			self._srsSymbol = SrsSymbol(self._core, self._base)
		return self._srsSymbol

	@property
	def tpc(self):
		"""tpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import Tpc
			self._tpc = Tpc(self._core, self._base)
		return self._tpc

	@property
	def trtiming(self):
		"""trtiming commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trtiming'):
			from .Trtiming import Trtiming
			self._trtiming = Trtiming(self._core, self._base)
		return self._trtiming

	@property
	def uciInd(self):
		"""uciInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uciInd'):
			from .UciInd import UciInd
			self._uciInd = UciInd(self._core, self._base)
		return self._uciInd

	@property
	def ufri(self):
		"""ufri commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ufri'):
			from .Ufri import Ufri
			self._ufri = Ufri(self._core, self._base)
		return self._ufri

	@property
	def ulPcrs(self):
		"""ulPcrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ulPcrs'):
			from .UlPcrs import UlPcrs
			self._ulPcrs = UlPcrs(self._core, self._base)
		return self._ulPcrs

	@property
	def utrTiming(self):
		"""utrTiming commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_utrTiming'):
			from .UtrTiming import UtrTiming
			self._utrTiming = UtrTiming(self._core, self._base)
		return self._utrTiming

	@property
	def xpend(self):
		"""xpend commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpend'):
			from .Xpend import Xpend
			self._xpend = Xpend(self._core, self._base)
		return self._xpend

	@property
	def xpRange(self):
		"""xpRange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpRange'):
			from .XpRange import XpRange
			self._xpRange = XpRange(self._core, self._base)
		return self._xpRange

	@property
	def xpStart(self):
		"""xpStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpStart'):
			from .XpStart import XpStart
			self._xpStart = XpStart(self._core, self._base)
		return self._xpStart

	def clone(self) -> 'DciConf':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DciConf(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delay:
	"""Delay commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("delay", core, parent)

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:COUPled:TRIGger:DELay:OFFSet \n
		Snippet: value: float = driver.source.bb.arbitrary.coupled.trigger.delay.get_offset() \n
		Sets a time delay to delay the waveform processing of a particular baseband. \n
			:return: offset: float Range: 0 to 2147483647/clockrate
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:COUPled:TRIGger:DELay:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:COUPled:TRIGger:DELay:OFFSet \n
		Snippet: driver.source.bb.arbitrary.coupled.trigger.delay.set_offset(offset = 1.0) \n
		Sets a time delay to delay the waveform processing of a particular baseband. \n
			:param offset: float Range: 0 to 2147483647/clockrate
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:COUPled:TRIGger:DELay:OFFSet {param}')



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.Utilities import trim_str_response
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Econfiguration:
	"""Econfiguration commands group definition. 137 total commands, 3 Sub-groups, 12 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("econfiguration", core, parent)

	@property
	def actable(self):
		"""actable commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_actable'):
			from .Actable import Actable
			self._actable = Actable(self._core, self._base)
		return self._actable

	@property
	def dcTable(self):
		"""dcTable commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dcTable'):
			from .DcTable import DcTable
			self._dcTable = DcTable(self._core, self._base)
		return self._dcTable

	@property
	def pconfiguration(self):
		"""pconfiguration commands group. 13 Sub-classes, 84 commands."""
		if not hasattr(self, '_pconfiguration'):
			from .Pconfiguration import Pconfiguration
			self._pconfiguration = Pconfiguration(self._core, self._base)
		return self._pconfiguration

	def get_ad_interval(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:ADINterval \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_ad_interval() \n
		Sets the time interval between two consecutive advertising events for packet type 'ADV_DIRECT_IND' and duty cycle high.
		Command sets the values in ms. Query returns values in s. \n
			:return: ad_interval: float Range: 1.05E-3 s to 3.75E-3 s , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:ADINterval?')
		return Conversions.str_to_float(response)

	def set_ad_interval(self, ad_interval: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:ADINterval \n
		Snippet: driver.source.bb.btooth.econfiguration.set_ad_interval(ad_interval = 1.0) \n
		Sets the time interval between two consecutive advertising events for packet type 'ADV_DIRECT_IND' and duty cycle high.
		Command sets the values in ms. Query returns values in s. \n
			:param ad_interval: float Range: 1.05E-3 s to 3.75E-3 s , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(ad_interval)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:ADINterval {param}')

	def get_ae_delay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:AEDelay \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_ae_delay() \n
		Sets a time delay between the start times of two consecutive advertising events. The value is added to the advertising
		event interval. Command sets the values in ms. Query returns values in s. \n
			:return: ae_delay: float Range: 0 s to 10E-3 s , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:AEDelay?')
		return Conversions.str_to_float(response)

	def set_ae_delay(self, ae_delay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:AEDelay \n
		Snippet: driver.source.bb.btooth.econfiguration.set_ae_delay(ae_delay = 1.0) \n
		Sets a time delay between the start times of two consecutive advertising events. The value is added to the advertising
		event interval. Command sets the values in ms. Query returns values in s. \n
			:param ae_delay: float Range: 0 s to 10E-3 s , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(ae_delay)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:AEDelay {param}')

	def get_ae_interval(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:AEINterval \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_ae_interval() \n
		Sets the time interval between two consecutive advertising events, with regard to the starting points. Command sets the
		values in ms. Query returns values in s. \n
			:return: ae_interval: float Range: 5E-3 s to depends on oversampling , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:AEINterval?')
		return Conversions.str_to_float(response)

	def set_ae_interval(self, ae_interval: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:AEINterval \n
		Snippet: driver.source.bb.btooth.econfiguration.set_ae_interval(ae_interval = 1.0) \n
		Sets the time interval between two consecutive advertising events, with regard to the starting points. Command sets the
		values in ms. Query returns values in s. \n
			:param ae_interval: float Range: 5E-3 s to depends on oversampling , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(ae_interval)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:AEINterval {param}')

	def get_ap_interval(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:APINterval \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_ap_interval() \n
		Sets the time interval between packets starting points of two consecutive packets in the advertising channel. \n
			:return: ap_interval: float Range: 1.3 to 28.0, Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:APINterval?')
		return Conversions.str_to_float(response)

	def set_ap_interval(self, ap_interval: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:APINterval \n
		Snippet: driver.source.bb.btooth.econfiguration.set_ap_interval(ap_interval = 1.0) \n
		Sets the time interval between packets starting points of two consecutive packets in the advertising channel. \n
			:param ap_interval: float Range: 1.3 to 28.0, Unit: ms
		"""
		param = Conversions.decimal_value_to_str(ap_interval)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:APINterval {param}')

	# noinspection PyTypeChecker
	def get_lc_mode(self) -> enums.BtoLlCnctMod:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LCMode \n
		Snippet: value: enums.BtoLlCnctMod = driver.source.bb.btooth.econfiguration.get_lc_mode() \n
		Selects the link layer connection mode. In order to provide safe transmission of payload data, the data in the packet can
		be encrypted. If activated, the payload data follows MIC (Message authentication Code) . \n
			:return: lc_mode: UENC| ENC UENC Payload data is transmitted without encoding. ENC The link layer connection runs in encrypted mode.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LCMode?')
		return Conversions.str_to_scalar_enum(response, enums.BtoLlCnctMod)

	def set_lc_mode(self, lc_mode: enums.BtoLlCnctMod) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LCMode \n
		Snippet: driver.source.bb.btooth.econfiguration.set_lc_mode(lc_mode = enums.BtoLlCnctMod.ENC) \n
		Selects the link layer connection mode. In order to provide safe transmission of payload data, the data in the packet can
		be encrypted. If activated, the payload data follows MIC (Message authentication Code) . \n
			:param lc_mode: UENC| ENC UENC Payload data is transmitted without encoding. ENC The link layer connection runs in encrypted mode.
		"""
		param = Conversions.enum_scalar_to_str(lc_mode, enums.BtoLlCnctMod)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LCMode {param}')

	# noinspection PyTypeChecker
	class LtKeyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lt_Key: List[str]: numeric
			- Bitcount: int: integer Range: 128 to 128"""
		__meta_args_list = [
			ArgStruct('Lt_Key', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lt_Key: List[str] = None
			self.Bitcount: int = None

	def get_lt_key(self) -> LtKeyStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LTKey \n
		Snippet: value: LtKeyStruct = driver.source.bb.btooth.econfiguration.get_lt_key() \n
		Indicates the time the controller needs to receive the long-term key from the host. After this time, the controller is
		ready to enter into the last phase of encryption mode setup. \n
			:return: structure: for return value, see the help for LtKeyStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LTKey?', self.__class__.LtKeyStruct())

	def set_lt_key(self, value: LtKeyStruct) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:LTKey \n
		Snippet: driver.source.bb.btooth.econfiguration.set_lt_key(value = LtKeyStruct()) \n
		Indicates the time the controller needs to receive the long-term key from the host. After this time, the controller is
		ready to enter into the last phase of encryption mode setup. \n
			:param value: see the help for LtKeyStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:LTKey', value)

	def get_pnumber(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PNUMber \n
		Snippet: value: int = driver.source.bb.btooth.econfiguration.get_pnumber() \n
		Sets the number of Tx packets per event. Each connection contains at least one data channel packet. The maximum number of
		packets per event is determined by the duration of the connection event interval. \n
			:return: pnumber: integer Range: 1 to depends on connection event interval
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PNUMber?')
		return Conversions.str_to_int(response)

	def set_pnumber(self, pnumber: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PNUMber \n
		Snippet: driver.source.bb.btooth.econfiguration.set_pnumber(pnumber = 1) \n
		Sets the number of Tx packets per event. Each connection contains at least one data channel packet. The maximum number of
		packets per event is determined by the duration of the connection event interval. \n
			:param pnumber: integer Range: 1 to depends on connection event interval
		"""
		param = Conversions.decimal_value_to_str(pnumber)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PNUMber {param}')

	def get_sdci(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:SDCI \n
		Snippet: value: int = driver.source.bb.btooth.econfiguration.get_sdci() \n
		Queries the number of the first active data channel. \n
			:return: selected_channel: integer Range: 0 to 36
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:SDCI?')
		return Conversions.str_to_int(response)

	def get_sinterval(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:SINTerval \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_sinterval() \n
		Sets the time interval between the starting points of two consecutive windows during which the scanner is operating in an
		advertising channel. Command sets the values in ms. Query returns values in s. \n
			:return: sinterval: float Range: 10E-3 s to depends on oversampling and the number of advertsing channel table states , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:SINTerval?')
		return Conversions.str_to_float(response)

	def set_sinterval(self, sinterval: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:SINTerval \n
		Snippet: driver.source.bb.btooth.econfiguration.set_sinterval(sinterval = 1.0) \n
		Sets the time interval between the starting points of two consecutive windows during which the scanner is operating in an
		advertising channel. Command sets the values in ms. Query returns values in s. \n
			:param sinterval: float Range: 10E-3 s to depends on oversampling and the number of advertsing channel table states , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(sinterval)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:SINTerval {param}')

	def get_swindow(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:SWINdow \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.get_swindow() \n
		Sets the length of the window during which the scanner is operating in the advertising channel. Note that the scan window
		is less or equal to the value of the scan interval. Command sets the values in ms. Query returns values in s. \n
			:return: swindow: float Range: 10E-3 s to 10240E-3 s , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:SWINdow?')
		return Conversions.str_to_float(response)

	def set_swindow(self, swindow: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:SWINdow \n
		Snippet: driver.source.bb.btooth.econfiguration.set_swindow(swindow = 1.0) \n
		Sets the length of the window during which the scanner is operating in the advertising channel. Note that the scan window
		is less or equal to the value of the scan interval. Command sets the values in ms. Query returns values in s. \n
			:param swindow: float Range: 10E-3 s to 10240E-3 s , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(swindow)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:SWINdow {param}')

	def get_wo_info(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:WOINfo \n
		Snippet: value: str = driver.source.bb.btooth.econfiguration.get_wo_info() \n
		(for data event and advertising frame configuration with the packet type CONNECT_IND) Queries the start point of the
		transmit window. \n
			:return: wo_info: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:WOINfo?')
		return trim_str_response(response)

	def get_ws_info(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:WSINfo \n
		Snippet: value: str = driver.source.bb.btooth.econfiguration.get_ws_info() \n
		(for data event and advertising frame configuration with the packet type CONNECT_IND) Queries the size of the transmit
		window, regarding to the start point. \n
			:return: ws_info: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:WSINfo?')
		return trim_str_response(response)

	def clone(self) -> 'Econfiguration':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Econfiguration(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Galileo:
	"""Galileo commands group definition. 4 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("galileo", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_file'):
			from .File import File
			self._file = File(self._core, self._base)
		return self._file

	def get_ud_source(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:GALileo:UDSource \n
		Snippet: value: bool = driver.source.bb.gnss.sv.importPy.galileo.get_ud_source() \n
		Enables loading the dedicated files as source for the navigation data. \n
			:return: use_diff_src_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:IMPort:GALileo:UDSource?')
		return Conversions.str_to_bool(response)

	def set_ud_source(self, use_diff_src_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:GALileo:UDSource \n
		Snippet: driver.source.bb.gnss.sv.importPy.galileo.set_ud_source(use_diff_src_state = False) \n
		Enables loading the dedicated files as source for the navigation data. \n
			:param use_diff_src_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(use_diff_src_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:GALileo:UDSource {param}')

	def clone(self) -> 'Galileo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Galileo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Refsig:
	"""Refsig commands group definition. 20 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("refsig", core, parent)

	@property
	def ansTx(self):
		"""ansTx commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ansTx'):
			from .AnsTx import AnsTx
			self._ansTx = AnsTx(self._core, self._base)
		return self._ansTx

	@property
	def drs(self):
		"""drs commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_drs'):
			from .Drs import Drs
			self._drs = Drs(self._core, self._base)
		return self._drs

	@property
	def srs(self):
		"""srs commands group. 16 Sub-classes, 0 commands."""
		if not hasattr(self, '_srs'):
			from .Srs import Srs
			self._srs = Srs(self._core, self._base)
		return self._srs

	def clone(self) -> 'Refsig':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Refsig(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sanity:
	"""Sanity commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sanity", core, parent)

	def get_cvalues(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SANity:CVALues \n
		Snippet: value: str = driver.source.bb.nr5G.sanity.get_cvalues() \n
		No command help available \n
			:return: current_values: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SANity:CVALues?')
		return trim_str_response(response)

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:BB:NR5G:SANity:STATe \n
		Snippet: value: bool = driver.source.bb.nr5G.sanity.get_state() \n
		No command help available \n
			:return: sanity_state: No help available
		"""
		response = self._core.io.query_str('SOURce:BB:NR5G:SANity:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, sanity_state: bool) -> None:
		"""SCPI: [SOURce]:BB:NR5G:SANity:STATe \n
		Snippet: driver.source.bb.nr5G.sanity.set_state(sanity_state = False) \n
		No command help available \n
			:param sanity_state: No help available
		"""
		param = Conversions.bool_to_str(sanity_state)
		self._core.io.write(f'SOURce:BB:NR5G:SANity:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def set(self, data: enums.DataSourceA, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:DATA \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.pusch.data.set(data = enums.DataSourceA.DLISt, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects the PUSCH data source of the selected UE. For the selected UE, this data source is used for the PUSCH channel in
		every subframe where this channel is configured. \n
			:param data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:PUSCh:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.eutra.uplink.ue.cell.pusch.data.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Selects the PUSCH data source of the selected UE. For the selected UE, this data source is used for the PUSCH channel in
		every subframe where this channel is configured. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:PUSCh:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mimo:
	"""Mimo commands group definition. 6 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mimo", core, parent)

	@property
	def apm(self):
		"""apm commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_apm'):
			from .Apm import Apm
			self._apm = Apm(self._core, self._base)
		return self._apm

	# noinspection PyTypeChecker
	def get_antenna(self) -> enums.OneWebSimAnt:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:MIMO:ANTenna \n
		Snippet: value: enums.OneWebSimAnt = driver.source.bb.oneweb.downlink.mimo.get_antenna() \n
		Queries the simulated antenna. \n
			:return: antenna: ANT1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:DL:MIMO:ANTenna?')
		return Conversions.str_to_scalar_enum(response, enums.OneWebSimAnt)

	# noinspection PyTypeChecker
	def get_configuration(self) -> enums.OneWebGlobMimoConf:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:MIMO:CONFiguration \n
		Snippet: value: enums.OneWebGlobMimoConf = driver.source.bb.oneweb.downlink.mimo.get_configuration() \n
		Queries the global MIMO configuration. \n
			:return: configuration: TX1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ONEWeb:DL:MIMO:CONFiguration?')
		return Conversions.str_to_scalar_enum(response, enums.OneWebGlobMimoConf)

	def clone(self) -> 'Mimo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mimo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Signal:
	"""Signal commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("signal", core, parent)

	def set(self, signal: enums.InpConnBbSignal, tmConnector=repcap.TmConnector.Default) -> None:
		"""SCPI: [SOURce<HW>]:INPut:TM<CH>:SIGNal \n
		Snippet: driver.source.inputPy.tm.signal.set(signal = enums.InpConnBbSignal.CLOCk, tmConnector = repcap.TmConnector.Default) \n
		Determines the control signal that is input at the selected connector. To define the connector direction, use the command
		method RsSmw.Source.InputPy.Tm.Direction.set. \n
			:param signal: TRIGger| CLOCk| FEEDback| DATA CLOCk is available only for TM1 DATA is available only for TM2 (default if custom digital modulation with external serial data is used) FEEDback is available only for TM3 (R&S SMW-B10) /TM2 (R&S SMW-B9)
			:param tmConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tm')"""
		param = Conversions.enum_scalar_to_str(signal, enums.InpConnBbSignal)
		tmConnector_cmd_val = self._base.get_repcap_cmd_value(tmConnector, repcap.TmConnector)
		self._core.io.write(f'SOURce<HwInstance>:INPut:TM{tmConnector_cmd_val}:SIGNal {param}')

	# noinspection PyTypeChecker
	def get(self, tmConnector=repcap.TmConnector.Default) -> enums.InpConnBbSignal:
		"""SCPI: [SOURce<HW>]:INPut:TM<CH>:SIGNal \n
		Snippet: value: enums.InpConnBbSignal = driver.source.inputPy.tm.signal.get(tmConnector = repcap.TmConnector.Default) \n
		Determines the control signal that is input at the selected connector. To define the connector direction, use the command
		method RsSmw.Source.InputPy.Tm.Direction.set. \n
			:param tmConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tm')
			:return: signal: TRIGger| CLOCk| FEEDback| DATA CLOCk is available only for TM1 DATA is available only for TM2 (default if custom digital modulation with external serial data is used) FEEDback is available only for TM3 (R&S SMW-B10) /TM2 (R&S SMW-B9)"""
		tmConnector_cmd_val = self._base.get_repcap_cmd_value(tmConnector, repcap.TmConnector)
		response = self._core.io.query_str(f'SOURce<HwInstance>:INPut:TM{tmConnector_cmd_val}:SIGNal?')
		return Conversions.str_to_scalar_enum(response, enums.InpConnBbSignal)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Real:
	"""Real commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("real", core, parent)

	def set(self, ant_mod_inv_mat_real: float, row=repcap.Row.Default, column=repcap.Column.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:ANTenna:INVerse:MATRix:ROW<ST>:COLumn<CH>:REAL \n
		Snippet: driver.source.fsimulator.mimo.antenna.inverse.matrix.row.column.real.set(ant_mod_inv_mat_real = 1.0, row = repcap.Row.Default, column = repcap.Column.Default) \n
		Sets the complex elements of the inverse channel matrix. \n
			:param ant_mod_inv_mat_real: No help available
			:param row: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Row')
			:param column: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Column')"""
		param = Conversions.decimal_value_to_str(ant_mod_inv_mat_real)
		row_cmd_val = self._base.get_repcap_cmd_value(row, repcap.Row)
		column_cmd_val = self._base.get_repcap_cmd_value(column, repcap.Column)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:ANTenna:INVerse:MATRix:ROW{row_cmd_val}:COLumn{column_cmd_val}:REAL {param}')

	def get(self, row=repcap.Row.Default, column=repcap.Column.Default) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:ANTenna:INVerse:MATRix:ROW<ST>:COLumn<CH>:REAL \n
		Snippet: value: float = driver.source.fsimulator.mimo.antenna.inverse.matrix.row.column.real.get(row = repcap.Row.Default, column = repcap.Column.Default) \n
		Sets the complex elements of the inverse channel matrix. \n
			:param row: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Row')
			:param column: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Column')
			:return: ant_mod_inv_mat_real: No help available"""
		row_cmd_val = self._base.get_repcap_cmd_value(row, repcap.Row)
		column_cmd_val = self._base.get_repcap_cmd_value(column, repcap.Column)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:MIMO:ANTenna:INVerse:MATRix:ROW{row_cmd_val}:COLumn{column_cmd_val}:REAL?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Alloc:
	"""Alloc commands group definition. 27 total commands, 8 Sub-groups, 0 group commands
	Repeated Capability: AllocationNull, default value after init: AllocationNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("alloc", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_allocationNull_get', 'repcap_allocationNull_set', repcap.AllocationNull.Nr0)

	def repcap_allocationNull_set(self, enum_value: repcap.AllocationNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AllocationNull.Default
		Default value after init: AllocationNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_allocationNull_get(self) -> repcap.AllocationNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import Conflict
			self._conflict = Conflict(self._core, self._base)
		return self._conflict

	@property
	def conType(self):
		"""conType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conType'):
			from .ConType import ConType
			self._conType = ConType(self._core, self._base)
		return self._conType

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBits
			self._physBits = PhysBits(self._core, self._base)
		return self._physBits

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def pucch(self):
		"""pucch commands group. 15 Sub-classes, 0 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import Pucch
			self._pucch = Pucch(self._core, self._base)
		return self._pucch

	@property
	def rbCount(self):
		"""rbCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbCount'):
			from .RbCount import RbCount
			self._rbCount = RbCount(self._core, self._base)
		return self._rbCount

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def vrbOffset(self):
		"""vrbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vrbOffset'):
			from .VrbOffset import VrbOffset
			self._vrbOffset = VrbOffset(self._core, self._base)
		return self._vrbOffset

	def clone(self) -> 'Alloc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Alloc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rmax:
	"""Rmax commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rmax", core, parent)

	def set(self, max_rep_npdcch: enums.EutraNbiotRmAx, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:NIOT:RMAX \n
		Snippet: driver.source.bb.eutra.downlink.user.niot.rmax.set(max_rep_npdcch = enums.EutraNbiotRmAx.R1, userIx = repcap.UserIx.Default) \n
		Sets the maximum number NPDCCH is repeated RMax. \n
			:param max_rep_npdcch: R1| R2| R4| R8| R16| R32| R64| R128| R256| R512| R1024| R2048
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(max_rep_npdcch, enums.EutraNbiotRmAx)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:NIOT:RMAX {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.EutraNbiotRmAx:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:NIOT:RMAX \n
		Snippet: value: enums.EutraNbiotRmAx = driver.source.bb.eutra.downlink.user.niot.rmax.get(userIx = repcap.UserIx.Default) \n
		Sets the maximum number NPDCCH is repeated RMax. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: max_rep_npdcch: R1| R2| R4| R8| R16| R32| R64| R128| R256| R512| R1024| R2048"""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:NIOT:RMAX?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotRmAx)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Triangle:
	"""Triangle commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("triangle", core, parent)

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import Period
			self._period = Period(self._core, self._base)
		return self._period

	@property
	def rise(self):
		"""rise commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rise'):
			from .Rise import Rise
			self._rise = Rise(self._core, self._base)
		return self._rise

	def clone(self) -> 'Triangle':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Triangle(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def set(self, data: enums.DataSourceA, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:USER<CH>:DATA \n
		Snippet: driver.source.bb.oneweb.downlink.user.data.set(data = enums.DataSourceA.DLISt, userIx = repcap.UserIx.Default) \n
		Selects the data source for the selected user configuration. \n
			:param data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:DL:USER{userIx_cmd_val}:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:USER<CH>:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.oneweb.downlink.user.data.get(userIx = repcap.UserIx.Default) \n
		Selects the data source for the selected user configuration. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: data: PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE"""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:USER{userIx_cmd_val}:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Clipping:
	"""Clipping commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("clipping", core, parent)

	def get_level(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:LEVel \n
		Snippet: value: int = driver.source.bb.tetra.clipping.get_level() \n
		Sets the limit for clipping. \n
			:return: level: integer Range: 1 to 100, Unit: PCT
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:CLIPping:LEVel?')
		return Conversions.str_to_int(response)

	def set_level(self, level: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:LEVel \n
		Snippet: driver.source.bb.tetra.clipping.set_level(level = 1) \n
		Sets the limit for clipping. \n
			:param level: integer Range: 1 to 100, Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:CLIPping:LEVel {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ClipMode:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:MODE \n
		Snippet: value: enums.ClipMode = driver.source.bb.tetra.clipping.get_mode() \n
		Selects the clipping method. \n
			:return: mode: VECTor| SCALar
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:CLIPping:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ClipMode)

	def set_mode(self, mode: enums.ClipMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:MODE \n
		Snippet: driver.source.bb.tetra.clipping.set_mode(mode = enums.ClipMode.SCALar) \n
		Selects the clipping method. \n
			:param mode: VECTor| SCALar
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ClipMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:CLIPping:MODE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:STATe \n
		Snippet: value: bool = driver.source.bb.tetra.clipping.get_state() \n
		Switches baseband clipping on and off. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:CLIPping:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:CLIPping:STATe \n
		Snippet: driver.source.bb.tetra.clipping.set_state(state = False) \n
		Switches baseband clipping on and off. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:CLIPping:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, usch_scram_state: bool, userNull=repcap.UserNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:USCH:SCRambling:STATe \n
		Snippet: driver.source.bb.nr5G.ubwp.user.usch.scrambling.state.set(usch_scram_state = False, userNull = repcap.UserNull.Default) \n
		Turns PUSCH scrambling on and off. \n
			:param usch_scram_state: 0| 1| OFF| ON
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')"""
		param = Conversions.bool_to_str(usch_scram_state)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:USCH:SCRambling:STATe {param}')

	def get(self, userNull=repcap.UserNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:USCH:SCRambling:STATe \n
		Snippet: value: bool = driver.source.bb.nr5G.ubwp.user.usch.scrambling.state.get(userNull = repcap.UserNull.Default) \n
		Turns PUSCH scrambling on and off. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:return: usch_scram_state: No help available"""
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:USCH:SCRambling:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Stream:
	"""Stream commands group definition. 15 total commands, 10 Sub-groups, 0 group commands
	Repeated Capability: Stream, default value after init: Stream.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("stream", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_stream_get', 'repcap_stream_set', repcap.Stream.Nr1)

	def repcap_stream_set(self, enum_value: repcap.Stream) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Stream.Default
		Default value after init: Stream.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_stream_get(self) -> repcap.Stream:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def antenna(self):
		"""antenna commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import Antenna
			self._antenna = Antenna(self._core, self._base)
		return self._antenna

	@property
	def bb(self):
		"""bb commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bb'):
			from .Bb import Bb
			self._bb = Bb(self._core, self._base)
		return self._bb

	@property
	def channels(self):
		"""channels commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_channels'):
			from .Channels import Channels
			self._channels = Channels(self._core, self._base)
		return self._channels

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import Conflict
			self._conflict = Conflict(self._core, self._base)
		return self._conflict

	@property
	def l1Band(self):
		"""l1Band commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_l1Band'):
			from .L1Band import L1Band
			self._l1Band = L1Band(self._core, self._base)
		return self._l1Band

	@property
	def l2Band(self):
		"""l2Band commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_l2Band'):
			from .L2Band import L2Band
			self._l2Band = L2Band(self._core, self._base)
		return self._l2Band

	@property
	def l5Band(self):
		"""l5Band commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_l5Band'):
			from .L5Band import L5Band
			self._l5Band = L5Band(self._core, self._base)
		return self._l5Band

	@property
	def output(self):
		"""output commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_output'):
			from .Output import Output
			self._output = Output(self._core, self._base)
		return self._output

	@property
	def rfBand(self):
		"""rfBand commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfBand'):
			from .RfBand import RfBand
			self._rfBand = RfBand(self._core, self._base)
		return self._rfBand

	@property
	def vehicle(self):
		"""vehicle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vehicle'):
			from .Vehicle import Vehicle
			self._vehicle = Vehicle(self._core, self._base)
		return self._vehicle

	def clone(self) -> 'Stream':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Stream(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Poffset:
	"""Poffset commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("poffset", core, parent)

	@property
	def pilot(self):
		"""pilot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pilot'):
			from .Pilot import Pilot
			self._pilot = Pilot(self._core, self._base)
		return self._pilot

	@property
	def tfci(self):
		"""tfci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tfci'):
			from .Tfci import Tfci
			self._tfci = Tfci(self._core, self._base)
		return self._tfci

	@property
	def tpc(self):
		"""tpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import Tpc
			self._tpc = Tpc(self._core, self._base)
		return self._tpc

	def clone(self) -> 'Poffset':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Poffset(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ssid:
	"""Ssid commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ssid", core, parent)

	def set(self, ssid: enums.GbasSsid, vdbTransmitter=repcap.VdbTransmitter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:SSID \n
		Snippet: driver.source.bb.gbas.vdb.ssid.set(ssid = enums.GbasSsid.A, vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the Station Slot Identifier SSID of the ground station. \n
			:param ssid: A| B| C| D| E| F| G| H
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')"""
		param = Conversions.enum_scalar_to_str(ssid, enums.GbasSsid)
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:SSID {param}')

	# noinspection PyTypeChecker
	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default) -> enums.GbasSsid:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:SSID \n
		Snippet: value: enums.GbasSsid = driver.source.bb.gbas.vdb.ssid.get(vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Sets the Station Slot Identifier SSID of the ground station. \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:return: ssid: A| B| C| D| E| F| G| H"""
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:SSID?')
		return Conversions.str_to_scalar_enum(response, enums.GbasSsid)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("waveform", core, parent)

	def set_create(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:WAVeform:CREate \n
		Snippet: driver.source.bb.nfc.waveform.set_create(filename = '1') \n
		Stores the current NFC signal as ARB signal in a waveform file with the filename given in the parameter. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:WAVeform:CREate {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ssid:
	"""Ssid commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ssid", core, parent)

	def set(self, ssid: str, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:BFConfiguration:SSID \n
		Snippet: driver.source.bb.wlnn.fblock.bfConfiguration.ssid.set(ssid = '1', frameBlock = repcap.FrameBlock.Default) \n
		Specifies the desired SSID or the wildcard SSID. \n
			:param ssid: string Range: 0 char to 32 char
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		param = Conversions.value_to_quoted_str(ssid)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:BFConfiguration:SSID {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:BFConfiguration:SSID \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.bfConfiguration.ssid.get(frameBlock = repcap.FrameBlock.Default) \n
		Specifies the desired SSID or the wildcard SSID. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: ssid: string Range: 0 char to 32 char"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:BFConfiguration:SSID?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpcch:
	"""Dpcch commands group definition. 8 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpcch", core, parent)

	@property
	def tpc(self):
		"""tpc commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import Tpc
			self._tpc = Tpc(self._core, self._base)
		return self._tpc

	def get_sformat(self) -> int:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:WSIGnal:DPCCh:SFORmat \n
		Snippet: value: int = driver.source.bb.w3Gpp.ts25141.wsignal.dpcch.get_sformat() \n
		Sets the slot format for the DPCCH. The slot format defines the FBI mode and the TFCI status. \n
			:return: sformat: integer Range: 0 to 5
		"""
		response = self._core.io.query_str('SOURce:BB:W3GPp:TS25141:WSIGnal:DPCCh:SFORmat?')
		return Conversions.str_to_int(response)

	def set_sformat(self, sformat: int) -> None:
		"""SCPI: [SOURce]:BB:W3GPp:TS25141:WSIGnal:DPCCh:SFORmat \n
		Snippet: driver.source.bb.w3Gpp.ts25141.wsignal.dpcch.set_sformat(sformat = 1) \n
		Sets the slot format for the DPCCH. The slot format defines the FBI mode and the TFCI status. \n
			:param sformat: integer Range: 0 to 5
		"""
		param = Conversions.decimal_value_to_str(sformat)
		self._core.io.write(f'SOURce:BB:W3GPp:TS25141:WSIGnal:DPCCh:SFORmat {param}')

	def clone(self) -> 'Dpcch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpcch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, ulca_cell_state: bool, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:CA:CELL<CH0>:STATe \n
		Snippet: driver.source.bb.oneweb.uplink.ca.cell.state.set(ulca_cell_state = False, cellNull = repcap.CellNull.Default) \n
		Activates the corresponding component carrier. \n
			:param ulca_cell_state: 0| 1| OFF| ON
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.bool_to_str(ulca_cell_state)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:UL:CA:CELL{cellNull_cmd_val}:STATe {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:CA:CELL<CH0>:STATe \n
		Snippet: value: bool = driver.source.bb.oneweb.uplink.ca.cell.state.get(cellNull = repcap.CellNull.Default) \n
		Activates the corresponding component carrier. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: ulca_cell_state: 0| 1| OFF| ON"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:CA:CELL{cellNull_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Beidou:
	"""Beidou commands group definition. 16 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("beidou", core, parent)

	@property
	def coordinates(self):
		"""coordinates commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coordinates'):
			from .Coordinates import Coordinates
			self._coordinates = Coordinates(self._core, self._base)
		return self._coordinates

	@property
	def location(self):
		"""location commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_location'):
			from .Location import Location
			self._location = Location(self._core, self._base)
		return self._location

	@property
	def svid(self):
		"""svid commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_svid'):
			from .Svid import Svid
			self._svid = Svid(self._core, self._base)
		return self._svid

	@property
	def synchronize(self):
		"""synchronize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_synchronize'):
			from .Synchronize import Synchronize
			self._synchronize = Synchronize(self._core, self._base)
		return self._synchronize

	@property
	def toaData(self):
		"""toaData commands group. 0 Sub-classes, 7 commands."""
		if not hasattr(self, '_toaData'):
			from .ToaData import ToaData
			self._toaData = ToaData(self._core, self._base)
		return self._toaData

	def clone(self) -> 'Beidou':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Beidou(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def set(self, power: float, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:POWer \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.power.set(power = 1.0, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the channel power relative to the powers of the other channels. This setting also determines the starting power of
		the channel for Misuse Output Power Control. With the command [:SOURce<hw>]:BB:C2K:POWer:ADJust, the power of all the
		activated channels is adapted so that the total power corresponds to 0 dB. This does not change the power ratio among the
		individual channels. For the traffic channels, this value is specific for the selected radio configuration. \n
			:param power: float Range: -80 to depends on channel
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')"""
		param = Conversions.decimal_value_to_str(power)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:POWer {param}')

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:POWer \n
		Snippet: value: float = driver.source.bb.c2K.bstation.cgroup.coffset.power.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the channel power relative to the powers of the other channels. This setting also determines the starting power of
		the channel for Misuse Output Power Control. With the command [:SOURce<hw>]:BB:C2K:POWer:ADJust, the power of all the
		activated channels is adapted so that the total power corresponds to 0 dB. This does not change the power ratio among the
		individual channels. For the traffic channels, this value is specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: power: float Range: -80 to depends on channel"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:POWer?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Config:
	"""Config commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("config", core, parent)

	def set(self, predefined_config: enums.DopplerConfig, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GPS:SDYNamics:CONFig \n
		Snippet: driver.source.bb.gnss.svid.gps.sdynamics.config.set(predefined_config = enums.DopplerConfig.USER, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Selects between the predefined velocity profiles or a user-defined one. \n
			:param predefined_config: USER| VEL1| VEL2 USER User-defined Profile parametrs are configurable. VEL1 Low dynamics Profile parametrs are read-only. VEL2 High dynamics Profile parametrs are read-only.
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.enum_scalar_to_str(predefined_config, enums.DopplerConfig)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GPS:SDYNamics:CONFig {param}')

	# noinspection PyTypeChecker
	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> enums.DopplerConfig:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GPS:SDYNamics:CONFig \n
		Snippet: value: enums.DopplerConfig = driver.source.bb.gnss.svid.gps.sdynamics.config.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Selects between the predefined velocity profiles or a user-defined one. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: predefined_config: USER| VEL1| VEL2 USER User-defined Profile parametrs are configurable. VEL1 Low dynamics Profile parametrs are read-only. VEL2 High dynamics Profile parametrs are read-only."""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GPS:SDYNamics:CONFig?')
		return Conversions.str_to_scalar_enum(response, enums.DopplerConfig)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class N16Qam:
	"""N16Qam commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("n16Qam", core, parent)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.GilterEdge:
		"""SCPI: [SOURce<HW>]:BB:GSM:FILTer:N16Qam:TYPE \n
		Snippet: value: enums.GilterEdge = driver.source.bb.gsm.filterPy.n16Qam.get_type_py() \n
		Queries filter for 16QAM signal. The filter is permanently set to GAUSS linearized. \n
			:return: type_py: LGAuss
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GSM:FILTer:N16Qam:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.GilterEdge)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal.RepeatedCapability import RepeatedCapability
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Echo:
	"""Echo commands group definition. 7 total commands, 7 Sub-groups, 0 group commands
	Repeated Capability: Echo, default value after init: Echo.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("echo", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_echo_get', 'repcap_echo_set', repcap.Echo.Nr1)

	def repcap_echo_set(self, enum_value: repcap.Echo) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Echo.Default
		Default value after init: Echo.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_echo_get(self) -> repcap.Echo:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def aazimuth(self):
		"""aazimuth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aazimuth'):
			from .Aazimuth import Aazimuth
			self._aazimuth = Aazimuth(self._core, self._base)
		return self._aazimuth

	@property
	def aelevation(self):
		"""aelevation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aelevation'):
			from .Aelevation import Aelevation
			self._aelevation = Aelevation(self._core, self._base)
		return self._aelevation

	@property
	def cpDrift(self):
		"""cpDrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cpDrift'):
			from .CpDrift import CpDrift
			self._cpDrift = CpDrift(self._core, self._base)
		return self._cpDrift

	@property
	def cphase(self):
		"""cphase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cphase'):
			from .Cphase import Cphase
			self._cphase = Cphase(self._core, self._base)
		return self._cphase

	@property
	def dshift(self):
		"""dshift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dshift'):
			from .Dshift import Dshift
			self._dshift = Dshift(self._core, self._base)
		return self._dshift

	@property
	def icPhase(self):
		"""icPhase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_icPhase'):
			from .IcPhase import IcPhase
			self._icPhase = IcPhase(self._core, self._base)
		return self._icPhase

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	def clone(self) -> 'Echo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Echo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 7 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	@property
	def noise(self):
		"""noise commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import Noise
			self._noise = Noise(self._core, self._base)
		return self._noise

	@property
	def sum(self):
		"""sum commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sum'):
			from .Sum import Sum
			self._sum = Sum(self._core, self._base)
		return self._sum

	def get_carrier(self) -> float:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:CARRier \n
		Snippet: value: float = driver.source.awgn.power.get_carrier() \n
		Sets the carrier power. \n
			:return: carrier: float
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:POWer:CARRier?')
		return Conversions.str_to_float(response)

	def set_carrier(self, carrier: float) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:CARRier \n
		Snippet: driver.source.awgn.power.set_carrier(carrier = 1.0) \n
		Sets the carrier power. \n
			:param carrier: float
		"""
		param = Conversions.decimal_value_to_str(carrier)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:POWer:CARRier {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.NoisAwgnPowMode:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:MODE \n
		Snippet: value: enums.NoisAwgnPowMode = driver.source.awgn.power.get_mode() \n
		Selects the mode for setting the noise level. \n
			:return: mode: CN| SN | EN
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:POWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.NoisAwgnPowMode)

	def set_mode(self, mode: enums.NoisAwgnPowMode) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:MODE \n
		Snippet: driver.source.awgn.power.set_mode(mode = enums.NoisAwgnPowMode.CN) \n
		Selects the mode for setting the noise level. \n
			:param mode: CN| SN | EN
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.NoisAwgnPowMode)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:POWer:MODE {param}')

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.NoisAwgnPowRefMode:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:RMODe \n
		Snippet: value: enums.NoisAwgnPowRefMode = driver.source.awgn.power.get_rmode() \n
		Determines whether the carrier or the noise level is kept constant when the C/N value or Eb/N0 value is changed. \n
			:return: rmode: CARRier| NOISe
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AWGN:POWer:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.NoisAwgnPowRefMode)

	def set_rmode(self, rmode: enums.NoisAwgnPowRefMode) -> None:
		"""SCPI: [SOURce<HW>]:AWGN:POWer:RMODe \n
		Snippet: driver.source.awgn.power.set_rmode(rmode = enums.NoisAwgnPowRefMode.CARRier) \n
		Determines whether the carrier or the noise level is kept constant when the C/N value or Eb/N0 value is changed. \n
			:param rmode: CARRier| NOISe
		"""
		param = Conversions.enum_scalar_to_str(rmode, enums.NoisAwgnPowRefMode)
		self._core.io.write(f'SOURce<HwInstance>:AWGN:POWer:RMODe {param}')

	def clone(self) -> 'Power':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Power(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Catalog:
	"""Catalog commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("catalog", core, parent)

	def get(self, frameIx=repcap.FrameIx.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:GSM:FRAMe<DI>:ULISt:CATalog \n
		Snippet: value: List[str] = driver.source.bb.gsm.frame.ulist.catalog.get(frameIx = repcap.FrameIx.Default) \n
		This command reads out the files with user defined frame settings in the default directory. The default directory is set
		using command method RsSmw.MassMemory.currentDirectory. Only files with the file extension *.gsm_fu and *.gsm_hfu are
		listed. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:return: catalog: string"""
		frameIx_cmd_val = self._base.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:ULISt:CATalog?')
		return Conversions.str_to_str_list(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dci:
	"""Dci commands group definition. 44 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dci", core, parent)

	@property
	def alloc(self):
		"""alloc commands group. 42 Sub-classes, 0 commands."""
		if not hasattr(self, '_alloc'):
			from .Alloc import Alloc
			self._alloc = Alloc(self._core, self._base)
		return self._alloc

	def get_awa_round(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:AWARound \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.emtc.dci.get_awa_round() \n
		If enabled, the PDSCH allocations are relocated at the beginning of the ARB sequence to ensure a consistent signal. \n
			:return: alloc_wrap_around: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:AWARound?')
		return Conversions.str_to_bool(response)

	def set_awa_round(self, alloc_wrap_around: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:AWARound \n
		Snippet: driver.source.bb.eutra.downlink.emtc.dci.set_awa_round(alloc_wrap_around = False) \n
		If enabled, the PDSCH allocations are relocated at the beginning of the ARB sequence to ensure a consistent signal. \n
			:param alloc_wrap_around: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(alloc_wrap_around)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:AWARound {param}')

	def get_nalloc(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:NALLoc \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.dci.get_nalloc() \n
		Sets the number of configurable DCIs. \n
			:return: dci_number_alloc: integer Range: 0 to 400
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:NALLoc?')
		return Conversions.str_to_int(response)

	def set_nalloc(self, dci_number_alloc: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:DCI:NALLoc \n
		Snippet: driver.source.bb.eutra.downlink.emtc.dci.set_nalloc(dci_number_alloc = 1) \n
		Sets the number of configurable DCIs. \n
			:param dci_number_alloc: integer Range: 0 to 400
		"""
		param = Conversions.decimal_value_to_str(dci_number_alloc)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:DCI:NALLoc {param}')

	def clone(self) -> 'Dci':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dci(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AckChannel:
	"""AckChannel commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ackChannel", core, parent)

	@property
	def gain(self):
		"""gain commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gain'):
			from .Gain import Gain
			self._gain = Gain(self._core, self._base)
		return self._gain

	@property
	def gating(self):
		"""gating commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gating'):
			from .Gating import Gating
			self._gating = Gating(self._core, self._base)
		return self._gating

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def values(self):
		"""values commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_values'):
			from .Values import Values
			self._values = Values(self._core, self._base)
		return self._values

	def clone(self) -> 'AckChannel':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AckChannel(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tdelay:
	"""Tdelay commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tdelay", core, parent)

	def set(self, tdelay: int, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:TDELay \n
		Snippet: driver.source.bb.tdscdma.up.cell.tdelay.set(tdelay = 1, cell = repcap.Cell.Default) \n
		Sets the time shift of the selected cell compared to cell 1; the time delay of cell 1 is 0. \n
			:param tdelay: integer Range: 0 to 19200, Unit: chip
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.decimal_value_to_str(tdelay)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:TDELay {param}')

	def get(self, cell=repcap.Cell.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:TDELay \n
		Snippet: value: int = driver.source.bb.tdscdma.up.cell.tdelay.get(cell = repcap.Cell.Default) \n
		Sets the time shift of the selected cell compared to cell 1; the time delay of cell 1 is 0. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: tdelay: integer Range: 0 to 19200, Unit: chip"""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:TDELay?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Range:
	"""Range commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("range", core, parent)

	def get_down(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:[ENHanced]:[DPDCh]:DPControl:RANGe:DOWN \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.dpControl.range.get_down() \n
		The command selects the dynamic range for ranging up the channel power. \n
			:return: down: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:DPControl:RANGe:DOWN?')
		return Conversions.str_to_float(response)

	def set_down(self, down: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:[ENHanced]:[DPDCh]:DPControl:RANGe:DOWN \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.dpdch.dpControl.range.set_down(down = 1.0) \n
		The command selects the dynamic range for ranging up the channel power. \n
			:param down: float Range: 0 to 60, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(down)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:DPControl:RANGe:DOWN {param}')

	def get_up(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:[ENHanced]:[DPDCh]:DPControl:RANGe:UP \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.enhanced.dpdch.dpControl.range.get_up() \n
		The command selects the dynamic range for ranging up the channel power. \n
			:return: up: float Range: 0 to 60, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:DPControl:RANGe:UP?')
		return Conversions.str_to_float(response)

	def set_up(self, up: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation:[ENHanced]:[DPDCh]:DPControl:RANGe:UP \n
		Snippet: driver.source.bb.w3Gpp.mstation.enhanced.dpdch.dpControl.range.set_up(up = 1.0) \n
		The command selects the dynamic range for ranging up the channel power. \n
			:param up: float Range: 0 to 60, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(up)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation:ENHanced:DPDCh:DPControl:RANGe:UP {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Update:
	"""Update commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("update", core, parent)

	@property
	def needed(self):
		"""needed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_needed'):
			from .Needed import Needed
			self._needed = Needed(self._core, self._base)
		return self._needed

	def set(self) -> None:
		"""SCPI: SYSTem:PCIFpga:UPDate \n
		Snippet: driver.system.pciFpga.update.set() \n
		No command help available \n
		"""
		self._core.io.write(f'SYSTem:PCIFpga:UPDate')

	def set_with_opc(self) -> None:
		"""SCPI: SYSTem:PCIFpga:UPDate \n
		Snippet: driver.system.pciFpga.update.set_with_opc() \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:PCIFpga:UPDate')

	def clone(self) -> 'Update':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Update(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrsResInd:
	"""SrsResInd commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("srsResInd", core, parent)

	def set(self, srs_res_ind: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:SRSResind \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.srsResInd.set(srs_res_ind = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the SRS resource indicator value. When multiple SRS resources are configured, an SRS resource indicator field in
		uplink DCI is used to indicate the selected SRS resource over whose antenna ports are used by the network to derive the
		precoding for uplink transmission. \n
			:param srs_res_ind: integer Range: 0 to 255
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')"""
		param = Conversions.decimal_value_to_str(srs_res_ind)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:SRSResind {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:SRSResind \n
		Snippet: value: int = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.srsResInd.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the SRS resource indicator value. When multiple SRS resources are configured, an SRS resource indicator field in
		uplink DCI is used to indicate the selected SRS resource over whose antenna ports are used by the network to derive the
		precoding for uplink transmission. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')
			:return: srs_res_ind: integer Range: 0 to 255"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:SRSResind?')
		return Conversions.str_to_int(response)
